@@ -1,5 +1,5 @@
-AUTHOR="CluBear"  
-VERSION="2020-04-17" 
+author="CluBear Reserch Group"  
+version="2020-04-18" 
 
 from .dm import manager
 from .pp import pump
@@ -9,5 +9,5 @@ from .sub import subsample
 from .pp import check
 
 from .fun import demo
-from .fun import dummy
+from .fun import ady
 from .fun import ispump
\ No newline at end of file
